StatusSink

Trait StatusSink 

pub trait StatusSink: Send + Sync {
    // Required method
    fn send_status(&self, msg: &str) -> impl Future<Output = ()> + Send + '_;
}
Abstract status sink for emitting short progress strings to the channel.

Implemented in zeph-core by a stack-local adapter wrapping Channel::send_status. Using a trait keeps this crate free of the Channel trait from zeph-core.

Required Methods

fn send_status(&self, msg: &str) -> impl Future<Output = ()> + Send + '_

Send a short status string to the active channel.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors