TrustGate

Trait TrustGate 

pub trait TrustGate: Send + Sync {
    // Required method
    fn set_effective_trust(&self, level: SkillTrustLevel);
}
Abstract gate for applying a skill trust level to the tool executor.

Implemented in zeph-core by a thin adapter over Arc<dyn ErasedToolExecutor>. Using a trait keeps this crate free of the tool executor abstraction.

Required Methods

fn set_effective_trust(&self, level: SkillTrustLevel)

Apply the given trust level to the underlying tool executor.

Implementors